@@ -1,6 +1,6 @@
 
 from messytables.util import offset_processor
-from messytables.headers import headers_guess, headers_processor
+from messytables.headers import headers_guess, headers_processor, headers_make_unique
 from messytables.types import type_guess, types_processor
 from messytables.types import StringType, IntegerType, FloatType, \
         DecimalType, DateType
@@ -9,4 +9,6 @@ from messytables.core import Cell, TableSet, RowSet
 from messytables.commas import CSVTableSet, CSVRowSet
 from messytables.excel import XLSTableSet, XLSRowSet
 from messytables.excelx import XLSXTableSet, XLSXRowSet
+from messytables.zip import ZIPTableSet
+from messytables.any import AnyTableSet
 
