@@ -1,28 +1,35 @@
 import decimal
 from datetime import datetime
 from collections import defaultdict
+from itertools import izip_longest
+import locale
 #from pprint import pprint
 
 from messytables.dateparser import DATE_FORMATS
 
+
 class CellType(object):
-    """ A cell type maintains information about the format 
-    of the cell, providing methods to check if a type is 
+    """ A cell type maintains information about the format
+    of the cell, providing methods to check if a type is
     applicable to a given value and to convert a value to the
     type. """
 
     guessing_weight = 1
 
+    def __init__(self):
+        if locale.getlocale() == (None, None):
+            locale.setlocale(locale.LC_ALL, '')
+
     @classmethod
     def test(cls, value):
-        """ Test if the value is of the given type. The 
-        default implementation calls ``cast`` and checks if 
+        """ Test if the value is of the given type. The
+        default implementation calls ``cast`` and checks if
         that throws an exception. """
         try:
             ins = cls()
             ins.cast(value)
             return ins
-        except: 
+        except:
             return None
 
     def cast(self, value):
@@ -39,6 +46,7 @@ class CellType(object):
     def __repr__(self):
         return self.__class__.__name__.rsplit('Type', 1)[0]
 
+
 class StringType(CellType):
     """ A string or other unconverted type. """
 
@@ -47,27 +55,34 @@ class StringType(CellType):
             raise ValueError()
         return value
 
+
 class IntegerType(CellType):
     """ An integer field. """
-    guessing_weight = 1.5
+    guessing_weight = 6
 
     def cast(self, value):
-        return int(value)
+        try:
+            return int(value)
+        except:
+            return locale.atoi(value)
+
 
 class FloatType(CellType):
     """ Floating point number. """
-    guessing_weight = 2
+    guessing_weight = 4
 
     def cast(self, value):
-        return float(value)
+        return locale.atof(value)
+
 
 class DecimalType(CellType):
     """ Decimal number, ``decimal.Decimal``. """
-    guessing_weight = 2.5
+    guessing_weight = 5
 
     def cast(self, value):
         return decimal.Decimal(value)
 
+
 class DateType(CellType):
     """ The date type is special in that it also includes a specific
     date format that is used to parse the date, additionally to the
@@ -85,7 +100,8 @@ class DateType(CellType):
             try:
                 ins.cast(value)
                 return ins
-            except: pass
+            except:
+                pass
 
     def cast(self, value):
         if self.format is None:
@@ -95,37 +111,48 @@ class DateType(CellType):
     def __eq__(self, other):
         return isinstance(other, DateType) and \
                 self.format == other.format
-    
+
     def __repr__(self):
         return "Date(%s)" % self.format
 
     def __hash__(self):
         return hash(self.__class__) + hash(self.format)
 
+
 TYPES = [StringType, IntegerType, FloatType, DecimalType, DateType]
 
-def type_guess(rows, types=TYPES):
-    """ The type guesser aggregates the number of successful 
-    conversions of each column to each type, weights them by a 
-    fixed type priority and select the most probable type for 
-    each column based on that figure. It returns a list of 
-    ``CellType``. """
+
+def type_guess(rows, types=TYPES, strict=False):
+    """ The type guesser aggregates the number of successful
+    conversions of each column to each type, weights them by a
+    fixed type priority and select the most probable type for
+    each column based on that figure. It returns a list of
+    ``CellType``. Empty cells are ignored.
+
+    Strict means that a type will not be guessed
+    if parsing fails for a single cell in the column."""
     guesses = defaultdict(lambda: defaultdict(int))
     for row in rows:
         for i, cell in enumerate(row):
             for type in types:
+                if not cell.value:
+                    continue
                 guess = type.test(cell.value)
-                if guess is not None:
-                    guesses[i][guess] += 1
-    for i, guess in guesses.items():
-        for type, count in guess.items():
-            guesses[i][type] *= type.guessing_weight
+                if guess is None:
+                    if strict:
+                        for key in guesses[i].keys():
+                            if isinstance(key, type):
+                                guesses[i][key] = None
+                else:
+                    if guesses[i][guess] is None:
+                        continue
+                    guesses[i][guess] += type.guessing_weight
     _columns = []
     for i, types in guesses.items():
         _columns.append(max(types.items(), key=lambda (t, n): n)[0])
     return _columns
 
-from itertools import izip_longest
+
 def types_processor(types):
     """ Apply the column types set on the instance to the
     current row, attempting to cast each cell to the specified
